/*
 * audio.c - Kedrigern (Milena TTS server for Raspberry Pi)
 * Copyright (C) Bohdan R. Rau 2019 <ethanak@polip.com>
 *
 * Kedrigern is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * Kedrigern is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Kedrigern.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <ao/ao.h>

static ao_device *device;
static ao_sample_format format;
static int default_driver;

void initAudio(const char *audiodev)
{
    ao_initialize();
    if (audiodev) default_driver = ao_driver_id(audiodev);
    else default_driver = ao_default_driver_id();
    if (default_driver == -1) {
        perror("Libao");
        exit(1);
    }
    memset(&format, 0, sizeof(format));
    format.bits = 16;
    format.channels = 1;
    format.rate = 16000;
    format.byte_format = AO_FMT_LITTLE;
}

void startAudio(int samplefreq)
{
    format.rate = samplefreq;
    device = ao_open_live(default_driver, &format, NULL);
	if (device == NULL) {
		fprintf(stderr, "Error opening device.\n");
		exit(1);
	}
}

void playSound(char *bufor, int n)
{
    ao_play(device, bufor, n);
}

void finalizeAudio(void)
{
    usleep(100000);
    ao_close(device);
}

void showAudioDrivers(void)
{
    ao_info ** aoi;
    int dcnt,i, wb = 0;
    char *c;
    ao_initialize();
    aoi = ao_driver_info_list(&dcnt);
    for (i=0;i<dcnt;i++) if (aoi[i] -> type == AO_TYPE_LIVE) {
        if (wb) printf("\n");
        printf("%s (%s)\n", aoi[i] -> short_name, aoi[i] -> name);
        c = aoi[i] -> comment;
        if (c && *c) {
            printf("%s\n", c);
        }
        wb = 1;
    }
}
